@@ -11,9 +11,7 @@
 <meta name="generator" content="<?cs var:html_escape(VERSION) ?>" />
 <link media="screen" href="<?cs var:html_escape(StaticURI) ?>/tdiary/base.css" rel="stylesheet" />
 <link media="screen" href="<?cs var:html_escape(StaticURI) ?>/tdiary/<?cs if:BBS_TYPE_THEME ?><?cs var:html_escape(BBS_TYPE_THEME) ?>/<?cs var:html_escape(BBS_TYPE_THEME) ?>.css<?cs else ?>default/default.css<?cs /if ?>" rel="stylesheet" />
-<script type="text/javascript" src="<?cs var:html_escape(StaticURI) ?>/js/jquery-1.1.js" charset="UTF-8"></script>
-<script type="text/javascript" src="<?cs var:html_escape(StaticURI) ?>/js/jquery/cookie.js" charset="UTF-8"></script>
-<script type="text/javascript" src="<?cs var:html_escape(StaticURI) ?>/js/img0ch/app.js" charset="UTF-8"></script>
+<script type="text/javascript" src="<?cs var:html_escape(StaticURI) ?>/js/img0ch.js" charset="UTF-8"></script>
 <script type="text/javascript">
 //<![CDATA[
 var app = Img0ch.App;
@@ -80,7 +78,7 @@ img { border: 0px; }
 <div class="day" id="thread_builder_form">
  <h2><span class="title">XbhVK쐬</span></h2>
  <div class="form">
-  <form class="comment" method="post" action="<?cs var:html_escape(CGIURI) ?>/bbs.cgi" enctype="multipart/form-data">
+  <form class="comment" method="post" action="<?cs var:html_escape(CGIURI) ?>/bbs.cgi?guid=on" enctype="multipart/form-data">
    <div class="hidden_field">
     <input type="hidden" name="bbs" value="<?cs var:html_escape(BBS) ?>" />
     <input type="hidden" name="time" value="<?cs var:html_escape(TimeStamp) ?>" />
