@@ -1,5 +1,5 @@
 #/*
-# *  Copyright 2007 hkrn <hikarin@users.sourceforge.jp>
+# *  Copyright 2007-2009 hkrn <hikarin@users.sourceforge.jp>
 # *
 # *  Licensed under the Apache License, Version 2.0 (the "License");
 # *  you may not use this file except in compliance with the License.
@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: Note.pm 1220 2007-09-30 12:24:42Z hikarin $
+# $Id: Note.pm 1827 2009-04-08 15:24:43Z hikarin $
 #
 
 package Img0ch::App::Note;
@@ -103,7 +103,7 @@ sub run {
             }
             )->{$action}
             || \&create_canvas;
-        $iApp->init() or return $iApp->redirect_error();
+        $iApp->init();
         eval {
             my ( $iTemplate, $ctype, $body ) = $action_method->($iApp);
             $iRequest->send_http_header( $ctype || 'text/html' );
