@@ -1,5 +1,5 @@
 #/*
-# *  Copyright 2007-2008 hkrn <hikarin@users.sourceforge.jp>
+# *  Copyright 2007-2009 hkrn <hikarin@users.sourceforge.jp>
 # *
 # *  Licensed under the Apache License, Version 2.0 (the "License");
 # *  you may not use this file except in compliance with the License.
@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: Read.pm 1645 2008-02-06 15:40:18Z hikarin $
+# $Id: Read.pm 1827 2009-04-08 15:24:43Z hikarin $
 #
 
 package Img0ch::App::Read;
@@ -104,7 +104,8 @@ sub thread { $_[0]->{_thread} }
 
 sub get_param {
     my ( $iApp, $key ) = @_;
-    return $iApp->{_extend_params}->{$key}
+    return
+           $iApp->{_extend_params}->{$key}
         || $iApp->{_request}->param($key)
         || '';
 }
@@ -145,7 +146,8 @@ sub load_thread {
         raw     => $raw,
     };
 
-    my $max = $iSetting->get_int('BBS_RES_MAX')
+    my $max 
+        = $iSetting->get_int('BBS_RES_MAX')
         || $iConfig->get_int('ResMAX')
         || 1000;
 
@@ -222,7 +224,8 @@ sub load_thread {
 
     my ( $reader, $read_res, $read_res_prev ) = ( undef, 100, 99 );
     if ($mobile) {
-        my $cnum = $iApp->get_param_int('RES')
+        my $cnum 
+            = $iApp->get_param_int('RES')
             || $iSetting->get_int('BBS_MB_CONTENTS_NUMBER')
             || 1;
         $read_res = $read_res_prev = $cnum;
@@ -429,7 +432,7 @@ sub init {
         $path[0] =~ /\A([\w\-]+)\z/xms;
         $bbs = $iApp->{_param_bbs} = $1;
         '0000000000' =~ /\A(\d+)\z/xms;
-        $path[1]     =~ /\A(\d{9,10})\z/xms;
+        $path[1] =~ /\A(\d{9,10})\z/xms;
         $key = $iApp->{_param_key} = $1;
 
         $iBBS = Img0ch::BBS->new( $iApp->{_kernel}, { bbs => $bbs } );
@@ -562,7 +565,7 @@ sub init {
     else {
         $iApp->get_param('bbs') =~ /([\w\-]+)/xms;
         $bbs = $iApp->{_param_bbs} = $1;
-        '0000000000'            =~ /\A(\d+)\z/xms;
+        '0000000000' =~ /\A(\d+)\z/xms;
         $iApp->get_param('key') =~ /(\d{9,10})/;
         $key = $iApp->{_param_key} = $1;
         $iApp->{_param_raw} = '';
@@ -584,7 +587,8 @@ sub init {
         my $read_from = Img0ch::Kernel::intval( $iApp->get_param('st') ) || 1;
         my $read_to = Img0ch::Kernel::intval( $iApp->get_param('to') )
             || $count;
-        $iApp->{_param_ls} = $last
+        $iApp->{_param_ls} 
+            = $last
             || $iApp->get_param('last')
             || $iApp->get_param('ls');
         my $single = $iApp->{_param_single}
