@@ -1,5 +1,5 @@
 #/*
-# *  Copyright 2007 hkrn <hikarin@users.sourceforge.jp>
+# *  Copyright 2007-2009 hkrn <hikarin@users.sourceforge.jp>
 # *
 # *  Licensed under the Apache License, Version 2.0 (the "License");
 # *  you may not use this file except in compliance with the License.
@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: BootStrap.pm 89 2007-01-12 13:50:47Z hikarin $
+# $Id: BootStrap.pm 1827 2009-04-08 15:24:43Z hikarin $
 #
 
 package Img0ch::CGI::BootStrap;
@@ -33,7 +33,7 @@ sub import {
     eval {
         $iConfig->load("${path}/img0ch-config.cgi");
         my $iKernel = Img0ch::Maple->new($iConfig);
-        eval "use ${app} qw(); 1;" or die $@;
+        Img0ch::Maple->load_module($app);
         $app->new($iKernel)->run();
         exit(0);
     };
