@@ -1,5 +1,5 @@
 #/*
-# *  Copyright 2007-2008 hkrn <hikarin@users.sourceforge.jp>
+# *  Copyright 2007-2009 hkrn <hikarin@users.sourceforge.jp>
 # *
 # *  Licensed under the Apache License, Version 2.0 (the "License");
 # *  you may not use this file except in compliance with the License.
@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: Request.pm 1645 2008-02-06 15:40:18Z hikarin $
+# $Id: Request.pm 1827 2009-04-08 15:24:43Z hikarin $
 #
 
 package Img0ch::FCGI::Request;
@@ -137,6 +137,11 @@ sub enable_compress {
     return;
 }
 
+sub enable_binary {
+    binmode STDOUT;
+    return;
+}
+
 sub send_http_header {
     my ( $iRequest, $type, $charset ) = @_;
     my $q = $iRequest->{__cgi};
