@@ -1,5 +1,5 @@
 #/*
-# *  Copyright 2007 hkrn <hikarin@users.sourceforge.jp>
+# *  Copyright 2007-2009 hkrn <hikarin@users.sourceforge.jp>
 # *
 # *  Licensed under the Apache License, Version 2.0 (the "License");
 # *  you may not use this file except in compliance with the License.
@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: Res.pm 1482 2007-10-25 12:58:17Z hikarin $
+# $Id: Res.pm 1827 2009-04-08 15:24:43Z hikarin $
 #
 
 package Img0ch::Filter::Res;
@@ -44,7 +44,13 @@ sub write_ok {
     my $latest_len  = 0;
     my $samba_count = 0;
 
-    my @data = split "\n", $iRepos->get_binary("I:F:R.${bbs}");
+    my @data      = split "\n", $iRepos->get_binary("I:F:R.${bbs}");
+    my $datacount = scalar @data;
+    my $timecount = $hash->{timecount};
+    if ( $datacount > $timecount ) {
+        @data = splice @data, ( $timecount * -1 );
+    }
+
     for my $datum (@data) {
         my $rec = [ split "\t", $datum ];
         ( $atime, $latest_len, $is_samba, undef ) = @$rec;
@@ -64,11 +70,6 @@ sub write_ok {
         return 1;
     }
 
-    if ( $my_count >= $can_store ) {
-        _flush( $iRepos, \@data, $bbs );
-        return 1;
-    }
-
     if ( !$hash->{samba_ok} ) {
         if ($is_samba) {
             my $wait = $hash->{samba_wait};
@@ -93,7 +94,6 @@ sub write_ok {
     }
 
     if ( !$hash->{throttle_ok} ) {
-        my $timecount = $hash->{timecount};
         my $throttle = $my_count > $timecount ? $timecount : $my_count;
         if ( $throttle >= $hash->{timeclose} ) {
             $hash->{error} = 'THROTTLED_POST';
