@@ -1,5 +1,5 @@
 #/*
-# *  Copyright 2007 hkrn <hikarin@users.sourceforge.jp>
+# *  Copyright 2007-2009 hkrn <hikarin@users.sourceforge.jp>
 # *
 # *  Licensed under the Apache License, Version 2.0 (the "License");
 # *  you may not use this file except in compliance with the License.
@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: VT.pm 1403 2007-10-16 13:34:05Z hikarin $
+# $Id: VT.pm 1827 2009-04-08 15:24:43Z hikarin $
 #
 
 package Img0ch::Plugin::BBS::VT;
@@ -39,7 +39,11 @@ sub init {
         map {
             $iSetting->set( $_,
                 ( $iTVirtual->get_setting($_) || $iSetting->get($_) ) )
-        } $iTVirtual->get_setting_string_keys();
+            } (
+            $iTVirtual->get_setting_string_keys(),
+            $iTVirtual->get_setting_hidden_string_keys(),
+            $iTVirtual->get_setting_boolean_keys(),
+            );
     }
 
     return 1;
@@ -53,14 +57,14 @@ sub filter {
         my ( $iBBS, $key ) = ( $iApp->bbs(), $iThread->get_key() );
         my $iCap = $iApp->cap();
         my $iTVirtual = Img0ch::Thread::Virtual->new( $iBBS, $key );
-        if ( !$iCap->can_pass_proxy_access()
+        if (   !$iCap->can_pass_proxy_access()
             and $iTVirtual->is_denied_remote_host( $iApp->get_remote_host() )
             )
         {
             $iApp->set_error('DENY_FROM_VT_LISTED_HOST');
             return 0;
         }
-        if ( !$iCap->can_pass_proxy_access()
+        if (   !$iCap->can_pass_proxy_access()
             and $iTVirtual->scan_text( $iApp->get_comment() ) )
         {
             $iApp->set_error('POST_WITH_NGWORD_IN_VT');
@@ -120,6 +124,11 @@ sub create {
                     : $iTVirtual->get_setting($setting_key) );
             }
 
+            for my $setting_key ( $iTVirtual->get_setting_boolean_keys() ) {
+                my $value = $iApp->get_annotation("VT:${setting_key}");
+                $iTVirtual->set_setting( $setting_key, $value );
+            }
+
             $iTVirtual->save();
         }
     }
