@@ -1,5 +1,5 @@
 #/*
-# *  Copyright 2007 hkrn <hikarin@users.sourceforge.jp>
+# *  Copyright 2007-2009 hkrn <hikarin@users.sourceforge.jp>
 # *
 # *  Licensed under the Apache License, Version 2.0 (the "License");
 # *  you may not use this file except in compliance with the License.
@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: BanASCII.pm 60 2006-12-31 00:29:40Z hikarin $
+# $Id: BanASCII.pm 1827 2009-04-08 15:24:43Z hikarin $
 #
 
 package Img0ch::Plugin::Filter::BanASCII;
@@ -25,19 +25,19 @@ sub is_ascii_only {
     my ($iApp) = @_;
 
     my $ret = eval {
-        require Encode;
+        defined $Encode::VERSION or require Encode;
         my $text = Encode::decode( 'shiftjis', $iApp->get_comment() );
         if ( $text =~ /\A[\x00-\xff]+\z/xms ) {
-            $iApp->set_error('INVALID_POST');
+            $iApp->set_error('DENY_POSTING_ASCII_ONLY');
             return 0;
         }
         return 1;
     };
     if ($@) {
-        require Unicode::Japanese;
-        my $icode = Unicode::Japanese->get_code( $iApp->get_comment() );
+        defined $Unicode::Japanese::VERSION or require Unicode::Japanese;
+        my $icode = Unicode::Japanese->getcode( $iApp->get_comment() );
         if ( $icode eq 'ascii' or $icode eq 'unknown' ) {
-            $iApp->set_error('INVALID_POST');
+            $iApp->set_error('DENY_POSTING_ASCII_ONLY');
             return 0;
         }
         else {
