@@ -1,5 +1,5 @@
 #/*
-# *  Copyright 2007 hkrn <hikarin@users.sourceforge.jp>
+# *  Copyright 2007-2009 hkrn <hikarin@users.sourceforge.jp>
 # *
 # *  Licensed under the Apache License, Version 2.0 (the "License");
 # *  you may not use this file except in compliance with the License.
@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: Upload.pm 1250 2007-10-02 14:14:25Z hikarin $
+# $Id: Upload.pm 1827 2009-04-08 15:24:43Z hikarin $
 #
 
 package Img0ch::Upload;
@@ -162,7 +162,7 @@ sub update_csv {
 }
 
 sub get {
-    my ( $iUpload, $resno ) = @_;
+    my ( $iUpload, $resno, $decode_base64 ) = @_;
     my $prefix = join '.', $iUpload->{_prefix}, $resno;
     my $iReposUpload = $iUpload->{_rs};
 
@@ -170,6 +170,8 @@ sub get {
         my $ext    = $iReposUpload->get("${prefix}.extension");
         my $width  = $iReposUpload->get_int("${prefix}.width");
         my $height = $iReposUpload->get_int("${prefix}.height");
+        $decode_base64
+            and $hash = unpack( 'H*', $iUpload->_decode_base64($hash) );
         return [ $ext, $width, $height, $hash ];
     }
     else {
@@ -555,15 +557,22 @@ sub remove {
     if ( ( -f $uploaded_file_path or -l $uploaded_file_path )
         and -w $uploaded_file_path )
     {
+        my $iBBS = $iUpload->{_i0_bbs};
+        my $key  = $iUpload->{_key};
         if ($save_removed_hash) {
-            require Img0ch::Upload::Removed;
-            my $iBBS      = $iUpload->{_i0_bbs};
-            my $key       = $iUpload->{_key};
-            my $iURemoved = Img0ch::Upload::Removed->new($iBBS);
+            defined &{'Img0ch::Upload::Removed::new'}
+                or require Img0ch::Upload::Removed;
+            my $iURemoved = $iUpload->{__removed}
+                ||= Img0ch::Upload::Removed->new($iBBS);
             $iURemoved->set( $iUpload->get_digest($uploaded_file_path),
                 $key, $resno );
             $iURemoved->save();
         }
+        defined &{'Img0ch::Upload::Tag::new'}
+            or require Img0ch::Upload::Tag;
+        my $iUTag = $iUpload->{__tag} ||= Img0ch::Upload::Tag->new($iBBS);
+        $iUTag->remove( $key, $resno );
+        $iUTag->save();
         my $iKernel = $iUpload->{_kernel};
         unlink $uploaded_file_path
             or $iKernel->throw_io_exception($uploaded_file_path);
@@ -586,6 +595,18 @@ sub remove {
     return 1;
 }
 
+sub _decode_base64 {
+    my ( $iUpload, $str ) = @_;
+    local $SIG{__WARN__} = sub { };
+    if ( defined $MIME::Base64::VERSION or eval 'require MIME::Base64; 1' ) {
+        return MIME::Base64::decode_base64($str);
+    }
+    else {
+        defined $MIME::Base64::Perl::VERSION or require MIME::Base64::Perl;
+        return MIME::Base64::Perl::decode_base64($str);
+    }
+}
+
 1;
 __END__
 
