@@ -14,13 +14,26 @@
 # *  limitations under the License.
 # */
 #
-# $Id: thread.pm 970 2007-08-21 14:52:15Z hikarin $
+# $Id: thread.pm 1824 2009-04-08 15:18:54Z hikarin $
 #
 
 package Zeromin2::App::thread;
 
 use strict;
 use Zeromin::Thread qw();
+use Zeromin2::App qw();
+
+BEGIN {
+    Zeromin2::App->install_alias( __PACKAGE__,
+        {   'freeze_file'        => [ 'upload', 'freeze_file' ],
+            'release_file'       => [ 'upload', 'release_file' ],
+            'deny_ip_local'      => [ 'filter', 'deny_ip_local' ],
+            'deny_ip_global'     => [ 'filter', 'deny_ip_global' ],
+            'deny_serial_local'  => [ 'filter', 'deny_serial_local' ],
+            'deny_serial_global' => [ 'filter', 'deny_serial_global' ],
+        }
+    );
+}
 
 sub load {
     my ($zApp) = @_;
@@ -34,15 +47,20 @@ sub load {
     my $reader   = Img0ch::App::Mock::Read->new( $iBBS, $key, $option );
     my $template_parameters = $reader->run();
 
-    require Img0ch::Log;
+    require Img0ch::Thread::Revision;
+    require Img0ch::Upload::Poll;
     require Zeromin2::Util;
-    my $iLog      = Img0ch::Log->new( $iBBS, $key );
-    my $privilege = $zApp->privilege('can_view_thread_log');
-    my $rewriter  = Zeromin2::Util::get_rewriter($zApp);
-    my $rslv      = $iRequest->param('resolve');
+    my $iLog       = $iBBS->get_log_instance($key);
+    my $iTRevision = Img0ch::Thread::Revision->new( $iBBS, $key );
+    my $iUPoll     = Img0ch::Upload::Poll->new( $iBBS, $key );
+    my $privilege  = $zApp->privilege('can_view_thread_log');
+    my $rewriter   = Zeromin2::Util::get_rewriter($zApp);
+    my $rslv       = $iRequest->param('resolve');
+
     for my $res ( @{ $template_parameters->{Thread} } ) {
+        my $resno = $res->{resno};
         if ($privilege) {
-            my $info = $iLog->get( $res->{resno} );
+            my $info = $iLog->get($resno);
             my $ip   = $info->[1];
             $ip = $ip ? join '.', unpack( 'C*', $ip ) : '(null)';
             $res->{ip}     = $ip;
@@ -56,6 +74,8 @@ sub load {
             $res->{serial} = '(null)';
             $res->{agent}  = '(null)';
         }
+        $res->{revision} = $iTRevision->get_latest_id();
+        $res->{poll_bad_count} = $iUPoll->count( $resno, 'BAD' );
         $rewriter->( \$res->{text} );
     }
 
@@ -63,10 +83,17 @@ sub load {
     $rewriter->( \$template_parameters->{FOOT} );
     $rewriter->( \$template_parameters->{Banner} );
     $rewriter->( \$template_parameters->{SubBanner} );
-    $template_parameters->{BBSName} = $iBBS->get_name();
-    $template_parameters->{Option}  = $option;
 
-    $zApp->add_template_param($template_parameters);
+    $zApp->add_template_param(
+        {   %$template_parameters,
+            BBSName        => $iBBS->get_name(),
+            IsTypeTemplate => (
+                $iBBS->get_setting_instance()->get('BBS_TEMPLATE')
+                    =~ /\Atype/xms ? 1 : 0
+            ),
+            Option => $option,
+        }
+    );
     $zApp->encoding('Shift_JIS');
     return $zApp->return_value(0);
 }
@@ -91,14 +118,13 @@ sub lookup {
         or return $zApp->return_value( 1, [] );
 
     require Data::Page;
-    require Img0ch::Log;
     require Zeromin2::Util;
 
     my $ret      = [];
     my $target   = $zApp->request()->param('target');
     my $iKernel  = $zApp->kernel();
     my $encoding = $iKernel->get_encoding(1);
-    my $iLog     = Img0ch::Log->new( $zApp->bbs(), 0 );
+    my $iLog     = $zApp->bbs()->get_log_instance(0);
     my $result   = $iLog->search($target);
     my $page     = Data::Page->new( scalar @$result, $zApp->page_param() );
 
@@ -126,43 +152,57 @@ sub edit_res {
     $zApp->privilege( 'can_edit_res', 1 ) or return $zApp->return_value(1);
 
     my $iBBS     = $zApp->bbs();
+    my $iKernel  = $zApp->kernel();
     my $key      = $zApp->key();
-    my $dir      = $iBBS->get_name();
     my $iRequest = $zApp->request();
-    my $resno    = $iRequest->param_int('resno');
+    my $resno    = $iRequest->param_int('resno') || 1;
     my ( $unijp, $encoding ) = $zApp->unijp();
 
-    require Zeromin::Thread;
     my $zThread = Zeromin::Thread->new( $iBBS, $key );
-    my $count = $zThread->load();
+    my $count = $zThread->load() or return $zApp->return_value(2);
     my $from
-        = $zApp->kernel()->get_config()->get('EnableEditName')
-        ? $iRequest->param_multibyte( 'FROM', $encoding, 1 )
+        = $iKernel->get_config()->get('EnableEditName')
+        ? $iKernel->get_encoded_str( $iRequest->param( 'FROM', 1 ),
+        undef, 'utf8' )
         : undef;
     defined $from and $from =~ tr/\r\t\n//d;
-    my $mail = $iRequest->param_multibyte( 'mail', $encoding );
+    my $mail = $iKernel->get_encoded_str( $iRequest->param('mail'), undef,
+        'utf8' );
     $mail =~ tr/\r\t\n//d;
-    my $message = $iRequest->param_multibyte( 'MESSAGE', $encoding, 1 );
+    my $message = $iKernel->get_encoded_str( $iRequest->param( 'MESSAGE', 1 ),
+        undef, 'utf8' );
     $message =~ tr/\t//d;
     $message =~ s/\r\n/\n/gxms;
     $message =~ s/\n/<br>/gxms;
-    $zThread->load();
+    my $subject
+        = ( $resno == 1 )
+        ? $iKernel->get_encoded_str( $iRequest->param( 'subject', 1 ),
+        undef, 'utf8' )
+        : undef;
 
-    if ( $zThread->edit( $resno, [ $from, $mail, undef, undef, $message ] ) )
+    if ($zThread->edit(
+            $resno, [ $from, $mail, undef, undef, $message, $subject ]
+        )
+        )
     {
         $zThread->save();
         $zApp->logger(
             1,
             'EDITED RES: %d at %s/dat/%s.dat',
-            [ $resno, $dir, $key ],
+            [ $resno, $iBBS->get_name(), $key ],
         );
+        if ($subject) {
+            my $iSubject = $iBBS->get_subject_instance();
+            $iSubject->sage( $key, $count, $subject );
+            $iSubject->save();
+        }
         return $zApp->return_value(0);
     }
     else {
         $zApp->logger(
             0,
             'TRIED EDITTING INEXISTING RES: %d at %s/dat/%s.dat',
-            [ $resno, $dir, $key ]
+            [ $resno, $iBBS->get_name(), $key ]
         );
         return $zApp->return_value(2);
     }
@@ -173,40 +213,39 @@ sub edit_res_form {
     $zApp->privilege( 'can_edit_res', 1 )
         or return $zApp->return_value(1);
 
-    require Img0ch::Setting;
-    require Img0ch::Thread;
+    my $iKernel  = $zApp->kernel();
     my $iBBS     = $zApp->bbs();
     my $key      = $zApp->key();
-    my $resno    = $zApp->request()->param_int('resno');
-    my $iSetting = Img0ch::Setting->new($iBBS);
-    my $iThread  = Img0ch::Thread->new( $iBBS, $key );
-    $iThread->load();
+    my $resno    = $zApp->request()->param_int('resno') || 1;
+    my $iSetting = $iBBS->get_setting_instance();
+    my $iThread  = $iBBS->get_thread_instance($key);
 
     my $res = $iThread->get($resno);
     my ( $unijp, $encoding ) = $zApp->unijp();
     my $text = $res->[4];
     $text =~ s/<[bB][rR]>/\n/gxms;
-    $text =~ s/\s+\n\s+/\n/gxms;
-    $text =~ s/\A\s+//xms;
-    $text =~ s/\s+\z//xms;
-    $text =~ s/\n+\z//xms;
 
     $zApp->add_template_param(
-        {   BBS_TITLE =>
-                $unijp->set( $iSetting->get('BBS_TITLE'), $encoding )->get(),
-            KEY   => $key,
-            Resno => $resno,
-            Subject =>
-                $unijp->set( $iThread->get_subject(), $encoding )->get(),
+        {   BBS_TITLE => $iKernel->get_encoded_str(
+                $iSetting->get('BBS_TITLE'),
+                'utf8', $encoding
+            ),
+            KEY     => $key,
+            Resno   => $resno,
+            Subject => $iKernel->get_encoded_str(
+                $iThread->get_subject(), 'utf8', $encoding
+            ),
+            IsFirstRes => ( $resno == 1 ? 1 : 0 ),
             IsNameEditable =>
                 $zApp->kernel()->get_config()->get('EnableEditName'),
             IsTypeTemplate =>
                 ( $iSetting->get('BBS_TEMPLATE') =~ /\Atype/xms ? 1 : 0 ),
-            Name => $unijp->set( $res->[0], $encoding )->get(),
-            Mail => $unijp->set( $res->[1], $encoding )->get(),
-            Date =>
-                $unijp->set( "$res->[2]&nbsp;$res->[3]", $encoding )->get(),
-            Message => $unijp->set( $text, $encoding )->get()
+            Name => $iKernel->get_encoded_str( $res->[0], 'utf8', $encoding ),
+            Mail => $iKernel->get_encoded_str( $res->[1], 'utf8', $encoding ),
+            Date => $iKernel->get_encoded_str(
+                "$res->[2]&nbsp;$res->[3]", 'utf8', $encoding
+            ),
+            Message => $unijp->set( $text, $encoding )->get(),
         }
     );
     return $zApp->return_value(0);
@@ -233,7 +272,6 @@ sub create_special {
     $zApp->privilege( 'can_edit_head', 1 ) or return $zApp->return_value(1);
 
     require Img0ch::App::BBS;
-    require Zeromin::Thread;
     require Zeromin::Thread::Special;
     my $iBBS = $zApp->bbs();
     my $iApp = Img0ch::App::BBS->new( $iBBS->get_kernel(),
@@ -257,18 +295,18 @@ sub create_special {
             $count = $zThread->count();
         }
         my $type = $count ? 'ADDED RES TO' : 'CREATED';
+        my $iKernel = $zApp->kernel();
+        my $subject
+            = $iKernel->get_encoded_str( $iApp->request()->param('subject'),
+            $iKernel->get_encoding(1), 'utf8' );
         $zThread->set(
-            [   $iApp->get_name(),
-                $iApp->get_mail,
-                @{ $iApp->get_date_and_id() },
-                $iApp->get_comment(),
-                ( $count ? '' : $iApp->get_subject() )
+            [   $iApp->get_name(),             $iApp->get_mail,
+                @{ $iApp->get_date_and_id() }, $iApp->get_comment(),
+                ( $count ? '' : $subject )
             ]
         );
         $zThread->save();
-        require Img0ch::Subject;
-        my $iSubject = Img0ch::Subject->new($iBBS);
-        $iSubject->load();
+        my $iSubject = $iBBS->get_subject_instance();
         $iSubject->age( $key, $zThread->count(), $zThread->get_subject() );
         $iSubject->save();
         $tp->{ ( $count ? 'IsAdded' : 'IsCreated' ) } = 1;
@@ -289,7 +327,7 @@ sub create_special {
 
 sub rewrite_all {
     my ($zApp) = @_;
-    $zApp->check_csrf()                or return $zApp->return_value(1);
+    $zApp->check_csrf() or return $zApp->return_value(1);
     $zApp->privilege('can_create_bbs') or return $zApp->return_value(1);
 
     my ( $unijp, undef ) = $zApp->unijp();
@@ -306,10 +344,8 @@ sub rewrite_all {
     }
     my $from_re = qr/$from/xms;
 
-    require Img0ch::Subject;
-    require Zeromin::Thread;
     my $iBBS     = $zApp->bbs();
-    my $iSubject = Img0ch::Subject->new($iBBS);
+    my $iSubject = $iBBS->get_subject_instance();
     my $zThread  = Zeromin::Thread->new( $iBBS, 0 );
     $iSubject->load();
 
@@ -335,24 +371,116 @@ sub rewrite_form {
     return $zApp->return_value(0);
 }
 
-sub deny_ip_local {
-    require Zeromin2::App::filter;
-    Zeromin2::App::filter::deny_ip_local(@_);
+sub load_revision {
+    my ($zApp) = @_;
+    $zApp->privilege( 'can_edit_res', 1 ) or return $zApp->return_value(1);
+
+    my $iKernel  = $zApp->kernel();
+    my $iRequest = $zApp->request();
+    my $iBBS     = $zApp->bbs();
+    my $key      = $zApp->key();
+    my $resno    = $iRequest->param_int('resno');
+
+    require Img0ch::Thread::Revision;
+    my $iSetting   = $iBBS->get_setting_instance();
+    my $iThread    = $iBBS->get_thread_instance($key);
+    my $iTRevision = Img0ch::Thread::Revision->new( $iBBS, $key );
+    my $latest     = $iTRevision->get_latest_id($resno) + 1;
+    my $revision   = $iRequest->param_int('revision') || $latest;
+    my $revisions  = $iTRevision->get_revisions($resno);
+    my $stack      = [];
+    my $fallback   = $iThread->get($resno);
+    my ( $fb_name, $fb_mail, $fb_date, $fb_id, $fb_message ) = @$fallback;
+
+    for my $one (@$revisions) {
+        my ( $rev, $content ) = @$one;
+        unshift @$stack,
+            {
+            revision => $rev,
+            name     => $content->[0],
+            mail     => $content->[1],
+            date     => $content->[2],
+            id       => $content->[3],
+            comment  => $content->[4],
+            selected => $rev == $revision,
+            };
+    }
+
+    unshift @$stack,
+        {
+        revision => $latest,
+        name     => $fb_name,
+        mail     => $fb_mail,
+        date     => $fb_date,
+        id       => $fb_id,
+        comment  => $fb_message,
+        selected => $latest == $revision,
+        };
+
+    my $encoding = $iKernel->get_encoding(1);
+    my $ret = $iTRevision->get( $resno, $revision );
+    my $fb_message_nobr = $fb_message;
+    $fb_message_nobr =~ s/<[bB][rR]>/\n/gxms;
+    $zApp->add_template_param(
+        {   BBS_TITLE => $iKernel->get_encoded_str(
+                $iSetting->get('BBS_TITLE'),
+                'utf8', $encoding
+            ),
+            CurrentId => $revision,
+            Date      => $iKernel->get_encoded_str(
+                ( $ret->[2] || $fb_date ),
+                'utf8', $encoding
+            ),
+            Id => $iKernel->get_encoded_str(
+                ( $ret->[3] || $fb_id ),
+                'utf8', $encoding
+            ),
+            KEY      => $key,
+            LatestId => $latest,
+            Mail     => $iKernel->get_encoded_str(
+                ( $ret->[1] || $fb_mail ),
+                'utf8', $encoding
+            ),
+            Message => $iKernel->get_encoded_str(
+                ( $ret->[4] || $fb_message_nobr ),
+                'utf8', $encoding
+            ),
+            Name => $iKernel->get_encoded_str(
+                ( $ret->[0] || $fb_name ),
+                'utf8', $encoding
+            ),
+            Resno     => $resno,
+            Revisions => $stack,
+            Subject   => $iKernel->get_encoded_str(
+                $iThread->get_subject(), 'utf8', $encoding
+            ),
+        }
+    );
+
+    return $zApp->return_value(0);
 }
 
-sub deny_ip_global {
-    require Zeromin2::App::filter;
-    Zeromin2::App::filter::deny_ip_global(@_);
-}
+sub revert_res {
+    my ($zApp) = @_;
+    $zApp->check_csrf() or return $zApp->return_value(1);
+    $zApp->privilege( 'can_edit_res', 1 ) or return $zApp->return_value(1);
 
-sub deny_serial_local {
-    require Zeromin2::App::filter;
-    Zeromin2::App::filter::deny_serial_local(@_);
-}
+    my $iBBS     = $zApp->bbs();
+    my $key      = $zApp->key();
+    my $iRequest = $zApp->request();
+    my $resno    = $iRequest->param_int('resno');
+    my $revision = $iRequest->param_int('revision');
 
-sub deny_serial_global {
-    require Zeromin2::App::filter;
-    Zeromin2::App::filter::deny_serial_global(@_);
+    my $zThread = Zeromin::Thread->new( $iBBS, $key );
+    $zThread->load();
+    $zThread->revert( { $resno => $revision } );
+    $zApp->logger(
+        1,
+        'REVERTED RES TO REVISION %d: %d at %s/dat/%s.dat',
+        [ $revision, $resno, $iBBS->get_name(), $key ],
+    );
+
+    return $zApp->return_value(0);
 }
 
 sub remove {
