@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: Util.pm 1481 2007-10-24 14:13:30Z hikarin $
+# $Id: Util.pm 1661 2008-03-09 23:53:39Z hikarin $
 #
 
 package Zeromin2::Util;
@@ -55,7 +55,8 @@ sub get_rewriter {
 
                 # from URI::Escape
                 Img0ch::Request->escape_uri( \$redirectTo );
-                return '<a href="' 
+                return
+                      '<a href="' 
                     . $url
                     . $redirectTo . '">'
                     . $caption . '</a>';
